===========
*pylogconf*
===========

.. image:: https://img.shields.io/pypi/v/pylogconf

.. image:: https://img.shields.io/github/license/veltzer/pylogconf

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg

project website: https://veltzer.github.io/pylogconf

author: Mark Veltzer

version: 0.0.31


